@@ -1,5 +1,5 @@
 /*=============================================================================
-  Copyright (C) 2003-2012 Fisheries and Oceans Canada
+  Copyright (C) 2003-2013 Fisheries and Oceans Canada
 
   This file is part of PBS Mapping.
 
@@ -185,14 +185,15 @@
 #include <math.h>
 #include <setjmp.h>
 
+#include <R.h>
+#include <Rdefines.h>
+
 #include "globals.h"
 #include "conversions.h"
 #include "polygons.h"
 #include "thin.h"
 #include "floating.h"
 
-#include "gpc.h"
-
 #ifdef _MCD_CHECK
 #include "mcd.h"
 #endif /* _MCD_CHECK */
@@ -251,8 +252,6 @@ int cornerXY[NUM_CORNERS][2] = {
   {EDGE_W, EDGE_S}
 };
 
-extern short gpc_success;
-
 jmp_buf returnLocation;
 
 /*-----------------------------------------------------------------------------
@@ -263,8 +262,7 @@ jmp_buf returnLocation;
   
     The polygon can optionally be closed: (x_0, y_0) == (x_n, y_n).
   
-  Author:
-    Nicholas Boers (June 13, 2003)
+  Author:  Nicholas Boers (June 13, 2003)
   ---------------------------------------------------------------------------*/
 void
 pnpoly(PBSINT *polyPts, double *polyX, double *polyY,
@@ -308,8 +306,7 @@ pnpoly(PBSINT *polyPts, double *polyX, double *polyY,
     This function determines the indices (0 .. n-1) where polygons
     start and end.
   
-  Author:
-    Nicholas Boers (June 11, 2003)
+  Author:  Nicholas Boers (June 11, 2003)
   
   Returns: 
     the number of polygons (start/end pairs).
@@ -357,8 +354,7 @@ polyStartsEnds(PBSINT *polyStarts, PBSINT *polyEnds,
   clip:
     This function clips polygons to a rectangular viewing window.
   
-  Author:
-    Nicholas Boers (June 11, 2003)
+  Author:  Nicholas Boers (June 11, 2003)
   
   Implementation Notes:
     For each pair of points that are tested, the _first_ point of the
@@ -463,601 +459,6 @@ clip(PBSINT *inID, double *inXY, PBSINT *inVerts, PBSINT *polygons,
 #endif /* _MCD_CHECK */
 }
 
-/*-----------------------------------------------------------------------------
-  gpcConvert:
-    This function converts an array of x-values and an array of y-values
-    to a gpc_vertex_list.
-
-  Author:
-    Nicholas Boers (May 10, 2004)
-
-  Notes:
-    PBSINT versus long: either should be OK for most invocations of this
-    function.
-
-  Returns:
-    NULL when insufficient memory.
-    *gpc_vertex_list on success.
-  ---------------------------------------------------------------------------*/
-static gpc_vertex_list *
-gpcConvert (double *x, double *y, PBSINT n)
-{
-  gpc_vertex_list *vertList;
-  gpc_vertex *verts;
-  PBSINT i;
-
-  vertList = (gpc_vertex_list *)malloc(sizeof(gpc_vertex_list));
-  if (vertList == NULL)
-    return NULL;
-
-  verts = (gpc_vertex *)malloc(sizeof(gpc_vertex) * n);
-  if (verts == NULL) {
-    FREE (vertList);
-    return NULL;
-  }
-
-  /* populate the vertices */
-  for (i = 0; i < n; i++) {
-    verts[i].x = x[i];
-    verts[i].y = y[i];
-  }
-
-  vertList->num_vertices = n;
-  vertList->vertex = verts;
-
-  return (vertList);
-}
-
-/*-----------------------------------------------------------------------------
-  gpcCreatePoly:
-  
-  Author:
-    Nicholas Boers (July 28, 2004)
-  
-  Notes:
-    PBSINT versus long: either should be OK for most invocations of this
-    function.
-
-  Returns:
-    NULL when insufficient memory.
-  ---------------------------------------------------------------------------*/
-static gpc_polygon *
-gpcCreatePoly (PBSINT *PID, PBSINT *POS, double *X, double *Y,
-               PBSINT *starts, PBSINT *ends, PBSINT *procPolys, PBSINT nPolys)
-{
-  gpc_vertex_list *contour;
-  gpc_polygon *poly = (gpc_polygon *)malloc(sizeof(gpc_polygon));
-  PBSINT currPID = PID[starts[*procPolys]];
-
-  /* initialize polygon */
-  if (!poly)
-    return (NULL);
-  poly->num_contours = 0;
-  poly->hole = NULL;
-  poly->contour = NULL;
-
-  while (((*procPolys) < nPolys) && (currPID == PID[starts[*procPolys]]))
-    {
-      PBSINT nVerts;
-      short isHole;
-      
-      nVerts = (ends[*procPolys] - starts[*procPolys] + 1);
-      if (nVerts > 1)
-        isHole = (POS[starts[*procPolys]] > POS[starts[*procPolys] + 1]);
-      else
-        isHole = FALSE;
-
-      /* create a contour to add to the polygon */
-      contour = gpcConvert(&X[starts[*procPolys]], &Y[starts[*procPolys]],
-                           nVerts);
-      if (!contour)
-        {
-          FREE(poly);
-          return (NULL);
-        }
-
-      if (setjmp(returnLocation) == 0) 
-        gpc_add_contour(poly, contour, isHole);
-
-      FREE(contour->vertex);
-      FREE(contour);
-
-      if (!gpc_success)
-        {
-          FREE(poly);
-          return (NULL);
-        }
-
-      (*procPolys)++;
-    }
-
-  return (poly);
-}
-
-/*-----------------------------------------------------------------------------
-  gpcOutputPoly:
-  
-  Author:
-    Nicholas Boers (July 28, 2004)
-  
-  Notes:
-    PBSINT versus long: either should be OK for most invocations of this
-    function.
-
-  Returns:
-    PBS_SUCCESS: OK
-    PBS_ERR_OUT: insufficient room in out*
-    PBS_ERR_MEM: insufficient memory
-    PBS_ERR_OT1: a hole was being processed more than once
-    PBS_ERR_OT2: a hole was not processed
-  ---------------------------------------------------------------------------*/
-static int
-gpcOutputPoly (gpc_polygon *results,
-               PBSINT *PID, PBSINT *SID, PBSINT *POS, double *X, double *Y,
-               PBSINT *outVerts, PBSINT curPID, PBSINT allocatedSpace)
-{
-  PBSINT curSID = 0;
-  short status;
-
-  /* declared global to the function so that GPC_FREE_MEM can free them */
-  double *polyX = NULL, *polyY = NULL;
-  PBSINT *pnpResults = NULL;
-  short *pnpResultsProcessed = NULL;
-
-  if (results->num_contours > 0)
-    {
-      PBSINT j;
-      PBSINT outerSearch = 0;
-      PBSINT nContours = results->num_contours;
-
-      polyX = (double *)malloc(sizeof(double) * nContours);
-      polyY = (double *)malloc(sizeof(double) * nContours);
-      pnpResults = NULL;
-      pnpResultsProcessed = (short *)malloc(sizeof(short) * nContours);
-      
-      if (!pnpResultsProcessed || !polyX || !polyY)
-        {
-          status = PBS_ERR_MEM;
-          goto GPC_OUTPUT_FREE_MEM;
-        }
-
-      /* initialize pnpResultsProcessed to FALSE, so we can later use it to
-         check that all holes were processed, and no holes are
-         processed twice */
-      memset((void *)pnpResultsProcessed, 0, sizeof(short) * nContours);
-          
-      /* set up for running pnpoly() in the loop below;
-         add the first vertex of each contour to the array; these
-         will be the points that we use in the points-in-polygons
-         routine */
-      for (j = 0; j < nContours; j++) 
-        {
-          polyX[j] = results->contour[j].vertex[0].x;
-          polyY[j] = results->contour[j].vertex[0].y;
-        }
-
-      /* loop, searching for 'outer' polygons */
-      while (outerSearch < nContours)
-        {
-          /* if we found an 'outer' polygon... */
-          if (!results->hole[outerSearch])
-            {
-              PBSINT v;
-              PBSINT polyPts = results->contour[outerSearch].num_vertices;
-              PBSINT firstVertex = *outVerts;
-              PBSINT pos;
-
-              /* verify that we have enough space for the output */
-              if (((*outVerts) + polyPts) > allocatedSpace) 
-                {
-                  status = PBS_ERR_OUT;
-                  goto GPC_OUTPUT_FREE_MEM;
-                }
-              /* "extract" all the points of the "outer" polygon */
-              pos = 1;
-              curSID++;
-              for (v = 0; v < polyPts; v++) 
-                {
-                  PID[*outVerts] = curPID;
-                  SID[*outVerts] = curSID;
-                  POS[*outVerts] = pos++;
-                  X[*outVerts] = results->contour[outerSearch].vertex[v].x;
-                  Y[*outVerts] = results->contour[outerSearch].vertex[v].y;
-                  (*outVerts)++;
-                }
-
-              pnpResults = (PBSINT *)malloc(sizeof(PBSINT) * nContours);
-              if (!pnpResults)
-                {
-                  status = PBS_ERR_MEM;
-                  goto GPC_OUTPUT_FREE_MEM;
-                }
-
-              /* run pnpoly() to find any holes that belong to this outer
-                 polygon -- we are running it on all polygons! */
-              /* pnpoly (and its dependencies) don't allocate any memory;
-                 no need to deal with insufficient memory errors */
-              pnpoly(&polyPts, &X[firstVertex], &Y[firstVertex],
-                     &nContours, polyX, polyY, pnpResults);
-
-              /* check the results from pnpoly() */
-              for (j = 0; j < nContours; j++) 
-                {
-                  /* add holes: each time, pnpResults[j] == BOUNDARY for
-                     the current outer polygon -- since it is an outer
-                     polygon, it isn't a hole */
-                  if ((pnpResults[j] != OUTSIDE) && (results->hole[j]))
-                    {
-                      /* if already processed, we have an error */
-                      if (pnpResultsProcessed[j])
-                        {
-                          status = PBS_ERR_OT1;
-                          goto GPC_OUTPUT_FREE_MEM;
-                        }
-                      /* add a flag to indicate this point is processed */
-                      pnpResultsProcessed[j] = TRUE;
-
-                      /* verify we have enough space for the vertex */
-                      if (((*outVerts) + results->contour[j].num_vertices) 
-                          > allocatedSpace)
-                        {
-                          status = PBS_ERR_OUT;
-                          goto GPC_OUTPUT_FREE_MEM;
-                        }
-                      pos = results->contour[j].num_vertices;
-                      curSID++;
-                      for (v = 0; v < results->contour[j].num_vertices; v++)
-                        {
-                          PID[*outVerts] = curPID;
-                          SID[*outVerts] = curSID;
-                          POS[*outVerts] = pos--;
-                          X[*outVerts] = results->contour[j].vertex[v].x;
-                          Y[*outVerts] = results->contour[j].vertex[v].y;
-                          (*outVerts)++;
-                        }
-                    } /* end of "add holes" */
-                } /* end of "check the results from pnpoly()" */
-                      
-              FREE(pnpResults);
-            } /* end of "if we found an 'outer' polygon... */
-
-          outerSearch++;
-        } /* end of "loop, searching for 'outer' polygons */
-      
-      /* check that all the holes were processed */
-      for (j = 0; j < nContours; j++) 
-        {
-          if ((results->hole[j]) && !pnpResultsProcessed[j])
-            {
-              status = PBS_ERR_OT2;
-              goto GPC_OUTPUT_FREE_MEM;
-            }
-        }
-
-      /* we've now processed the results from clipping */
-      FREE(pnpResultsProcessed);
-      FREE(polyX);
-      FREE(polyY);
-    }
-      
-  status = PBS_SUCCESS;
-
- GPC_OUTPUT_FREE_MEM:
-  FREE(polyX);
-  FREE(polyY);
-  FREE(pnpResults);
-  FREE(pnpResultsProcessed);
-
-  return (status);
-}
-
-/*-----------------------------------------------------------------------------
-  nPIDs:
-  
-  Author:
-    Nicholas Boers (July 29, 2004)
-  
-  Returns:
-    0: no PIDs
-    1: 1 PID
-    2: 2+ PIDs
-  ---------------------------------------------------------------------------*/
-static short
-nPIDs (PBSINT *PID, PBSINT *starts, PBSINT nPolys)
-{
-  if (nPolys > 0)
-    {
-      PBSINT curPID = PID[starts[0]];
-      PBSINT i;
-
-      for (i = 1; i < nPolys; i++)
-        if (curPID != PID[starts[i]])
-          return 2;
-
-      return 1;
-    }
-
-  return 0;
-}
-
-/*-----------------------------------------------------------------------------
-  joinPolys:
-    This function interfaces PBS Mappping with the GPC (General Polygon
-    Clipper) library.
-
-  Notes:
-    If (*clipVerts == 0), there is no clip polygon.  In that case, work way
-    through the polygons in in*.
-
-  Returns:
-    PBS_SUCCESS: on success
-    PBS_ERR_MEM: insufficient memory
-    PBS_ERR_OUT: insufficient space allocated for out*
-  * PBS_ERR_OT1: when processing the results, a hole was
-      being processed more than once
-  * PBS_ERR_OT2: when processing the results, a hole was
-      not processed
-    PBS_ERR_OT3: missing subject polygon
-    PBS_ERR_OT4: subject polygon must contain more than 1 generic polygon
-      if no clip polygon specified
-  
-    * these arguments are set in gpcOutputPoly
-
-  Author:
-    Nicholas Boers (May 10, 2004)
-  ---------------------------------------------------------------------------*/
-void 
-joinPolys(PBSINT *operation,
-          PBSINT *subID, double *subXY, PBSINT *subVerts,
-          PBSINT *clipID, double *clipXY, PBSINT *clipVerts,
-          PBSINT *outID, double *outXY, PBSINT *outVerts,
-          PBSINT *status)
-{
-  /* DECLARATIONS - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  /* to make accessing values user-friendly */
-  PBSINT *subPID = subID;
-  PBSINT *subSID = subID + (*subVerts);
-  PBSINT *subPOS = subID + (2 * (*subVerts));
-  double *subX = subXY;
-  double *subY = subXY + (*subVerts);
-  
-  PBSINT *clipPID = clipID;
-  PBSINT *clipSID = clipID + (*clipVerts);
-  PBSINT *clipPOS = clipID + (2 * (*clipVerts));
-  double *clipX = clipXY;
-  double *clipY = clipXY + (*clipVerts);
-
-  PBSINT *outPID = outID;
-  PBSINT *outSID = outID + (*outVerts);
-  PBSINT *outPOS = outID + (2 * (*outVerts));
-  double *outX = outXY;
-  double *outY = outXY + (*outVerts);
-
-  /* for counting */
-  PBSINT subPolys, clipPolys;                   /* number of polys */
-  PBSINT procSubPolys = 0, procClipPolys = 0;   /* number of processed polys */
-
-  /* miscellaneous */
-  PBSINT allocatedSpace = *outVerts;
-  int curPID = 0;                               /* init. to 0; on clip, inc. */
-  short nSubPIDs = 0, nClipPIDs = 0;
-
-  enum {
-    RESET,
-    MAINT_SUB,
-    MAINT_CLIP
-  };
-  short maintPID = RESET;                       /* 0 = no, 1 = sub, 2 = clip */
-
-  /* pointers to dynamically-allocated arrays */
-  PBSINT *subStarts = NULL,  *subEnds = NULL;   /* for polyStartsEnd() */
-  PBSINT *clipStarts = NULL, *clipEnds = NULL;  /* for polyStartsEnd() */
-
-  /* for GPC */
-  gpc_polygon *polySubject = NULL, *polyClip = NULL, *polyResult = NULL;
-
-  /* BODY - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
-  /* determine starts/ends of each polygon */
-  (*outVerts) = 0;
-  subStarts  = (PBSINT *)malloc(sizeof(PBSINT) * (*subVerts));
-  subEnds    = (PBSINT *)malloc(sizeof(PBSINT) * (*subVerts));
-  clipStarts = (PBSINT *)malloc(sizeof(PBSINT) * (*clipVerts));
-  clipEnds   = (PBSINT *)malloc(sizeof(PBSINT) * (*clipVerts));
-  if (!subStarts || !subEnds || !clipStarts || !clipEnds)
-    {
-      (*status) = PBS_ERR_MEM;
-      goto JOINPOLYS_FREE_MEM;
-    }
-  subPolys = polyStartsEnds(subStarts, subEnds, subPID, subSID, subVerts);
-  clipPolys = polyStartsEnds(clipStarts, clipEnds, clipPID, clipSID, clipVerts);
-
-  if (subPolys == 0)
-    {
-      (*status) = PBS_ERR_OT3;
-      goto JOINPOLYS_FREE_MEM;
-    }
-
-  /* determine the length of unique PIDs in both the subject and the clip
-     polygon; if greater than 1, set the number to 2 */
-  nSubPIDs = nPIDs(subPID, subStarts, subPolys);
-  nClipPIDs = nPIDs(clipPID, clipStarts, clipPolys);
-  if ((nClipPIDs == 0) || ((nSubPIDs == 2) && (nClipPIDs == 2)))
-    maintPID = RESET;           /* no */
-  else if (nClipPIDs == 1)
-    maintPID = MAINT_SUB;       /* subject */
-  else
-    {
-      if (*operation == 0) /* diff */
-        maintPID = MAINT_SUB;   /* subject */
-      else
-        maintPID = MAINT_CLIP;  /* clip */
-    }
-
-  /* Idea:
-     We will walk through each generic polygon (PID), adding its contours
-     (outer and inner contours) to the GPC polygon.
-
-     Given both subject and clip polygons, we want our output to look like:
-       subject     clip
-       ----------------
-       s_1    op   c_1
-       ...
-       s_m    op   c_1
-       ...
-       s_1    op   c_n
-       ...
-       s_m    op   c_n
-
-    Given only a subject polygon, we want our output to look like:
-       (((s_1 op s_2) op s_3) ... op s_n)
-  */
-
-  procClipPolys = 0;
-  while ((procClipPolys < clipPolys) || (procClipPolys == 0))
-    {
-      /* if possible, read the next clip polygon */
-      if (procClipPolys < clipPolys)
-        {
-          polyClip = gpcCreatePoly(clipPID, clipPOS, clipX, clipY, 
-                                   clipStarts, clipEnds, &procClipPolys, 
-                                   clipPolys);
-          if (polyClip == NULL)
-            {
-              (*status) = PBS_ERR_MEM;
-              goto JOINPOLYS_FREE_MEM;
-            }
-        }
-      /* if no clip polys, increment procClipPolys to prevent the loop from
-         repeating */
-      if (procClipPolys == 0)
-        procClipPolys++;
-
-      procSubPolys = 0;
-      while (procSubPolys < subPolys)
-        {
-          /* read the next subject polygon */
-          polySubject = gpcCreatePoly(subPID, subPOS, subX, subY,
-                                      subStarts, subEnds, &procSubPolys,
-                                      subPolys);
-          if (polySubject == NULL)
-            {
-              (*status) = PBS_ERR_MEM;
-              goto JOINPOLYS_FREE_MEM;
-            }
-             
-          /* special handling for no "clip polygon" */
-          if (clipPolys == 0)
-            {
-              if (polyResult == NULL)
-                {
-                  /* if there's not clip polygon, user must supply more than
-                     one unique PID in subject PolySet */
-                  if (procSubPolys >= subPolys)
-                    {
-                      (*status) = PBS_ERR_OT4;
-                      goto JOINPOLYS_FREE_MEM;
-                    }
-                  polyResult = polySubject;
-                  polySubject = NULL;
-                  continue;
-                }
-              polyClip = polySubject;
-              polySubject = polyResult;
-            }
-
-          /* create the result polygon */
-          polyResult = (gpc_polygon *)malloc(sizeof(gpc_polygon));
-          if (polyResult == NULL)
-            {
-              (*status) = PBS_ERR_MEM;
-              goto JOINPOLYS_FREE_MEM;
-            }
-          polyResult->num_contours = 0;
-          polyResult->hole = NULL;
-          polyResult->contour = NULL;
-      
-          /* clip */
-          if (setjmp(returnLocation) == 0)
-            gpc_polygon_clip(*operation, polySubject, polyClip, polyResult);
-          if (!gpc_success)
-            {
-              (*status) = PBS_ERR_MEM;
-              goto JOINPOLYS_FREE_MEM;
-            }
-
-          /* free subject polygon */
-          gpc_free_polygon(polySubject);
-          FREE(polySubject);
-
-          /* special handling for no "clip polygon"; only grab next one and
-             continue if a next one exists */
-          if ((clipPolys == 0) && (procSubPolys < subPolys))
-            {
-              gpc_free_polygon(polyClip);
-              FREE(polyClip);
-              continue;
-            }
-
-          /* appropriately set the PID */
-          if (maintPID == RESET)                /* create new PIDs */
-            curPID++;
-          else if (maintPID == MAINT_SUB)       /* maintain subject PIDs */
-            curPID = subPID[subStarts[procSubPolys-1]];
-          else                          /* maintain clip PIDs */
-            curPID = clipPID[clipStarts[procClipPolys-1]];
-
-          /* output the results */
-          if (polyResult->num_contours > 0)
-            {
-              short i;
-              i = gpcOutputPoly (polyResult, outPID, outSID, outPOS, outX,
-                                 outY, outVerts, curPID, allocatedSpace);
-              if (i != PBS_SUCCESS)
-                {
-                  (*status) = i;
-                  goto JOINPOLYS_FREE_MEM;
-                }
-            }
-          gpc_free_polygon(polyResult);
-          FREE(polyResult);
-        }
-
-      gpc_free_polygon(polyClip);
-      FREE(polyClip);
-    }
-
-  (*status) = PBS_SUCCESS;
-
- JOINPOLYS_FREE_MEM:
-  FREE(subStarts);
-  FREE(subEnds);
-  FREE(clipStarts);
-  FREE(clipEnds);
-  if (polySubject) { gpc_free_polygon(polySubject); FREE(polySubject); }
-  if (polyClip) { gpc_free_polygon(polyClip); FREE(polyClip); }
-  if (polyResult) { gpc_free_polygon(polyResult); FREE(polyResult); }
-  
-#ifdef _MCD_CHECK
-  showMemStats();
-#endif /* _MCD_CHECK */
-}
-
-  /* code to print out gpc's polygons 
-     {
-       PBSINT j, k;
-
-       Rprintf ("subject:\n");
-       for (j = 0; j < polySubject->num_contours; j++) {
-         Rprintf ("contour: %d\n", j);
-         for (k = 0; k < polySubject->contour[j].num_vertices; k++) {
-           Rprintf ("(%f,%f)\n",
-           polySubject->contour[j].vertex[k].x,
-           polySubject->contour[j].vertex[k].y);
-         }
-       }
-     }
-  */
-
 #define ROLL_ADD_PT(pid, sid, pos, x, y)                                      \
           {                                                                   \
             outPID[*outVerts] = pid;                                          \
@@ -1095,8 +496,7 @@ joinPolys(PBSINT *operation,
        0 = don't add
        1 = add
 
-  Author:
-    Nicholas Boers (June 17, 2004)
+  Author:  Nicholas Boers (June 17, 2004)
   
   Status values:
     PBS_SUCCESS: everything OK
@@ -1302,8 +702,7 @@ void rollupPolys(PBSINT *inID, double *inPOS, double *inXY, PBSINT *inVerts,
     Given two points (stored in X and Y), returns the corner that is
     closest to one of those points.
   
-  Author:
-    Nicholas Boers
+  Author:  Nicholas Boers
   ---------------------------------------------------------------------------*/
 static corner
 findClosestCorner(double x[2], double y[2], double *limits)
@@ -1332,8 +731,7 @@ findClosestCorner(double x[2], double y[2], double *limits)
   closePolys: 
     "Fix" the closure of open polygons.
  
-  Author:
-    Nicholas Boers
+  Author:  Nicholas Boers
   
   Notes:
     - recommended allocated space for out*: 
@@ -1557,8 +955,7 @@ closePolys(PBSINT *inID, double *inXY, PBSINT *inVerts, double *limits,
   findCells:
     Identify integers within a vector of break points.
 
-  Author:
-    Nicholas Boers (Mar. 29, 2006)
+  Author:  Nicholas Boers (Mar. 29, 2006)
 
   Notes:
     Some ideas from "findInterval()" in R source code.
@@ -1622,8 +1019,7 @@ findCells(double *inPt, PBSINT *inPts,
   findPolys:
     Locate events within a polyset.
   
-  Author:
-    Nicholas Boers
+  Author:  Nicholas Boers
   
   Notes:
     - recommended allocated space for out*: 
@@ -1749,8 +1145,7 @@ findPolys(PBSINT *inEventsID, double *inEventsXY, PBSINT *inEvents,
   convUL:
     Convert Lon/Lat <--> UTME/UTMN.
   
-  Author:
-    Nicholas Boers
+  Author:  Nicholas Boers
   
   Notes:
     Maximum space required for out*:
@@ -1811,8 +1206,7 @@ convUL(double *inXY, PBSINT *inVerts, PBSINT *toUTM, PBSINT *zone,
     This function calculates the areas of a set of polygons.
     It handles holes, but has no concept of projection.
   
-  Author:
-    Nicholas Boers (July 11, 2003)
+  Author:  Nicholas Boers (July 11, 2003)
 
   Capabilities:
     [Y] Holes
@@ -1910,8 +1304,7 @@ calcArea(PBSINT *inID, double *inXY, PBSINT *inVerts,
     "integrated" (holes have the same PID/SID as their parent). It has no
     concept of projection.
   
-  Author:
-    Nicholas Boers (June 10, 2004)
+  Author:  Nicholas Boers (June 10, 2004)
 
   Capabilities:
     [>] Holes
@@ -2006,8 +1399,7 @@ calcCentroid(PBSINT *inID, double *inXY, PBSINT *inVerts,
     counter-clockwise).  Holes are irrelevant and it needs no concept of
     projection.
   
-  Author:
-    Nicholas Boers (June 9, 2004)
+  Author:  Nicholas Boers (June 9, 2004)
 
   Capabilities:
     [-] Holes
@@ -2093,8 +1485,7 @@ calcOrientation(PBSINT *inID, double *inXY, PBSINT *inVerts,
   isConvex:
     Determines whether a PolySet contains convex polygons.
 
-  Author:
-    Nicholas Boers (June 30, 2004)
+  Author:  Nicholas Boers (June 30, 2004)
   
   Status values:
     PBS_SUCCESS:    everything OK
@@ -2176,8 +1567,7 @@ isConvex(PBSINT *inID, double *inXY, PBSINT *inVerts,
     numericResult: if TRUE, returns a numeric result (a count); otherwise,
       returns a Boolean for whether or not the polygon self-intersects
 
-  Author:
-    Nicholas Boers (June 28, 2004)
+  Author:  Nicholas Boers (June 28, 2004)
   
   Status values:
     PBS_SUCCESS:    everything OK
@@ -2260,8 +1650,7 @@ isIntersecting(PBSINT *inID, double *inXY, PBSINT *inVerts,
   thickenPolys:
     This function thickens polygons.
   
-  Author:
-    Nicholas Boers (June 8, 2004)
+  Author:  Nicholas Boers (June 8, 2004)
   
   Notes:
     - if units == 0, "LL": tolerance in kilometers and inXY in decimal-degrees
@@ -2358,8 +1747,7 @@ thickenPolys(PBSINT *inID, double *inXY, PBSINT *inVerts,
   thinPolys:
     This function thins polygons.
   
-  Author:
-    Nicholas Boers (May 4, 2004)
+  Author:  Nicholas Boers (May 4, 2004)
   
   Notes:
     - X and Y are `PBSINT,' rather than the usual double
